@@ -3,7 +3,7 @@ import os, sys, inspect, platform
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
 parentdir = os.path.dirname(currentdir)
 sys.path.insert(0, parentdir)
-sys.path.insert(0, parentdir+"/simple_emulator")
+sys.path.insert(0, parentdir+"/net_emulator")
 # print(sys.path)
 
 from objects.emulator import SimpleEmulator
